@@ -439,7 +439,7 @@ def multisemideviation(X: np.ndarray, p=1) -> np.float64:
 
     Returns
     ----------
-        : float
+        : np.float64
             Multisemideviation score.
 
     See Also
@@ -451,6 +451,13 @@ def multisemideviation(X: np.ndarray, p=1) -> np.float64:
     ----------
     .. [1] "Seminorm", https://mathworld.wolfram.com/Seminorm.html
     .. [2] "Seminorm", https://en.wikipedia.org/wiki/Seminorm
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> multisemideviation(data)
+    7381024072265624.0
     '''
     result = X - np.mean(X, axis=0)
     result = np.prod(result, axis=1)
@@ -485,6 +492,13 @@ def signum_correlation(X: np.ndarray) -> np.float64:
     Notes
     -----
     On the face of it this coefficient seems the same as Kendall's :math:`\\tau` due to taking products of signs, however they are distinct. Kendall's :math:`\\tau` computes an average of the discordant pairs subtracted from the concordant pairs of points.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> signum_correlation(data)
+    0.9999999999999998
     '''
     transform = X - np.mean(X, axis=0)
     transform = np.sign(transform)
@@ -495,12 +509,6 @@ def taylor_correlation(X: np.ndarray) -> np.float64:
     '''
     Taylor's multi-way correlation coefficient.
 
-    References
-    ----------
-    .. [1] Taylor, BM. 2020. "A Multi-Way Correlation Coefficient", https://arxiv.org/abs/2003.02561
-
-    Notes
-    -----
     Taylor 2020 defines this function to be
 
     .. math::
@@ -509,8 +517,31 @@ def taylor_correlation(X: np.ndarray) -> np.float64:
 
     where :math:`d` is the number of variables, :math:`\lambda_1, \cdots, \lambda_d` are the eigenvalues of
     the correlation matrix for a given set of variables, and :math:`\\bar{\\lambda}` is the mean of those eigenvalues.
-    Thus Taylor's multi-way correlation coefficient is a rescaling of the Bessel-corrected standard deviation of the
+
+    Parameters
+    ----------
+    X : array-like
+        m x n data matrix
+
+    Returns
+    : np.float64
+        Taylor correlation score
+
+    Notes
+    -----
+    Taylor's multi-way correlation coefficient is a rescaling of the Bessel-corrected standard deviation of the
     eigenvalues of the correlation matrix of the set of variables.
+
+    References
+    ----------
+    .. [1] Taylor, BM. 2020. "A Multi-Way Correlation Coefficient", https://arxiv.org/abs/2003.02561
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> taylor_correlation(data)
+    0.9486832980505138
     '''
     d = X.shape[1]
     result = np.corrcoef(X)
@@ -541,6 +572,15 @@ def trencevski_malceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
     References
     ----------
     .. [1] Trencevski, Kostadin. Malceski, Risto. 2006. "On a generalized n-inner product and the corresponding Cauchy-Schwarz inequality", https://www.researchgate.net/publication/268999118_On_a_generalized_n-inner_product_and_the_corresponding_Cauchy-Schwarz_inequality
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> np.random.seed(0)
+    >>> Y = np.random.normal(size=1000).reshape(100,10)
+    >>> X = np.random.normal(size=1000).reshape(100,10)
+    >>> trencevski_malceski_correlation(X,Y)
+    3.1886981411745035e-08
     '''
     numerator = np.linalg.det(X.T @ Y)
     denominator = np.linalg.det(X.T @ X) *\
@@ -583,6 +623,13 @@ def wang_zheng_correlation(X: np.ndarray) -> np.float64:
     References
     ----------
     .. [1] Wang, Jianji. Zheng, Nanning. 2014. "Measures of Correlation for Multiple Variables", https://arxiv.org/abs/1401.4827
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> conaction.estimators.wang_zheng_correlation(data)
+    1.0
     '''
     result = X.T
     result = np.corrcoef(result)
